@@ -25,14 +25,19 @@ mod doc_var;
 mod drawing;
 mod fld_char;
 mod font;
+mod font_scheme;
 mod footer_reference;
 mod grid_span;
 mod header_reference;
 mod highlight;
+mod hyperlink;
 mod indent;
 mod indent_level;
 mod insert;
+mod instr_pageref;
+mod instr_tc;
 mod instr_text;
+mod instr_toc;
 mod italic;
 mod italic_cs;
 mod justification;
@@ -54,6 +59,7 @@ mod page_margin;
 mod page_size;
 mod paragraph;
 mod paragraph_property;
+mod paragraph_property_change;
 mod paragraph_style;
 mod pic;
 mod q_format;
@@ -65,6 +71,7 @@ mod section;
 mod section_property;
 mod shading;
 mod start;
+mod strike;
 mod structured_data_tag;
 mod structured_data_tag_property;
 mod style;
@@ -82,6 +89,7 @@ mod table_grid;
 mod table_indent;
 mod table_layout;
 mod table_of_contents;
+mod table_of_contents_item;
 mod table_property;
 mod table_row;
 mod table_row_property;
@@ -128,14 +136,19 @@ pub use doc_var::*;
 pub use drawing::*;
 pub use fld_char::*;
 pub use font::*;
+pub use font_scheme::*;
 pub use footer_reference::*;
 pub use grid_span::*;
 pub use header_reference::*;
 pub use highlight::*;
+pub use hyperlink::*;
 pub use indent::*;
 pub use indent_level::*;
 pub use insert::*;
+pub use instr_pageref::*;
+pub use instr_tc::*;
 pub use instr_text::*;
+pub use instr_toc::*;
 pub use italic::*;
 pub use italic_cs::*;
 pub use justification::*;
@@ -157,6 +170,7 @@ pub use page_margin::*;
 pub use page_size::*;
 pub use paragraph::*;
 pub use paragraph_property::*;
+pub use paragraph_property_change::*;
 pub use paragraph_style::*;
 pub use pic::*;
 pub use q_format::*;
@@ -168,6 +182,7 @@ pub use section::*;
 pub use section_property::*;
 pub use shading::*;
 pub use start::*;
+pub use strike::*;
 pub use structured_data_tag::*;
 pub use structured_data_tag_property::*;
 pub use style::*;
@@ -185,6 +200,7 @@ pub use table_grid::*;
 pub use table_indent::*;
 pub use table_layout::*;
 pub use table_of_contents::*;
+pub use table_of_contents_item::*;
 pub use table_property::*;
 pub use table_row::*;
 pub use table_row_property::*;
