@@ -32,6 +32,7 @@ pub enum ParagraphChild {
     Insert(Insert),
     Delete(Delete),
     BookmarkStart(BookmarkStart),
+    Hyperlink(Hyperlink),
     BookmarkEnd(BookmarkEnd),
     CommentStart(Box<CommentRangeStart>),
     CommentEnd(CommentRangeEnd),
@@ -44,6 +45,7 @@ impl BuildXML for ParagraphChild {
             ParagraphChild::Run(v) => v.build(),
             ParagraphChild::Insert(v) => v.build(),
             ParagraphChild::Delete(v) => v.build(),
+            ParagraphChild::Hyperlink(v) => v.build(),
             ParagraphChild::BookmarkStart(v) => v.build(),
             ParagraphChild::BookmarkEnd(v) => v.build(),
             ParagraphChild::CommentStart(v) => v.build(),
@@ -77,6 +79,12 @@ impl Serialize for ParagraphChild {
                 t.serialize_field("data", r)?;
                 t.end()
             }
+            ParagraphChild::Hyperlink(ref r) => {
+                let mut t = serializer.serialize_struct("hyperlink", 2)?;
+                t.serialize_field("type", "hyperlink")?;
+                t.serialize_field("data", r)?;
+                t.end()
+            }
             ParagraphChild::BookmarkStart(ref r) => {
                 let mut t = serializer.serialize_struct("BookmarkStart", 2)?;
                 t.serialize_field("type", "bookmarkStart")?;
@@ -130,6 +138,27 @@ impl Paragraph {
         self
     }
 
+    pub(crate) fn unshift_run(mut self, run: Run) -> Paragraph {
+        self.children.insert(0, ParagraphChild::Run(Box::new(run)));
+        self
+    }
+
+    pub(crate) fn wrap_by_bookmark(mut self, id: usize, name: impl Into<String>) -> Paragraph {
+        self.children.insert(
+            0,
+            ParagraphChild::BookmarkStart(BookmarkStart::new(id, name)),
+        );
+        self.children
+            .push(ParagraphChild::BookmarkEnd(BookmarkEnd::new(id)));
+
+        self
+    }
+
+    pub fn add_hyperlink(mut self, link: Hyperlink) -> Self {
+        self.children.push(ParagraphChild::Hyperlink(link));
+        self
+    }
+
     pub fn add_structured_data_tag(mut self, t: StructuredDataTag) -> Self {
         self.children
             .push(ParagraphChild::StructuredDataTag(Box::new(t)));
@@ -201,8 +230,13 @@ impl Paragraph {
         self
     }
 
-    pub fn window_control(mut self, v: bool) -> Self {
-        self.property = self.property.window_control(v);
+    pub fn widow_control(mut self, v: bool) -> Self {
+        self.property = self.property.widow_control(v);
+        self
+    }
+
+    pub fn add_tab(mut self, t: Tab) -> Self {
+        self.property = self.property.add_tab(t);
         self
     }
 
@@ -262,6 +296,50 @@ impl Paragraph {
         self.property = self.property.line_spacing(spacing);
         self
     }
+
+    pub fn delete(mut self, author: impl Into<String>, date: impl Into<String>) -> Self {
+        self.property.run_property.del = Some(Delete::new().author(author).date(date));
+        self
+    }
+
+    pub fn insert(mut self, author: impl Into<String>, date: impl Into<String>) -> Self {
+        self.property.run_property.ins = Some(Insert::new_with_empty().author(author).date(date));
+        self
+    }
+
+    pub fn paragraph_property_change(mut self, p: ParagraphPropertyChange) -> Self {
+        self.property = self.property.paragraph_property_change(p);
+        self
+    }
+
+    pub fn raw_text(&self) -> String {
+        let mut s = "".to_string();
+        // For now support only run and ins.
+        for c in self.children.iter() {
+            match c {
+                ParagraphChild::Insert(i) => {
+                    for c in i.children.iter() {
+                        if let InsertChild::Run(r) = c {
+                            for c in r.children.iter() {
+                                if let RunChild::Text(t) = c {
+                                    s.push_str(&t.text);
+                                }
+                            }
+                        }
+                    }
+                }
+                ParagraphChild::Run(run) => {
+                    for c in run.children.iter() {
+                        if let RunChild::Text(t) = c {
+                            s.push_str(&t.text);
+                        }
+                    }
+                }
+                _ => {}
+            }
+        }
+        s
+    }
 }
 
 impl BuildXML for Paragraph {
@@ -361,7 +439,7 @@ mod tests {
         let p = Paragraph::new().add_run(run);
         assert_eq!(
             serde_json::to_string(&p).unwrap(),
-            r#"{"id":"12345678","children":[{"type":"run","data":{"runProperty":{"sz":null,"szCs":null,"color":null,"highlight":null,"vertAlign":null,"underline":null,"bold":null,"boldCs":null,"italic":null,"italicCs":null,"vanish":null,"characterSpacing":null,"fonts":null,"textBorder":null,"del":null,"ins":null},"children":[{"type":"text","data":{"preserveSpace":true,"text":"Hello"}}]}}],"property":{"runProperty":{"sz":null,"szCs":null,"color":null,"highlight":null,"vertAlign":null,"underline":null,"bold":null,"boldCs":null,"italic":null,"italicCs":null,"vanish":null,"characterSpacing":null,"fonts":null,"textBorder":null,"del":null,"ins":null},"style":null,"numberingProperty":null,"alignment":null,"indent":null,"lineSpacing":null,"keepNext":false,"keepLines":false,"pageBreakBefore":false,"windowControl":false,"outlineLvl":null,"divId":null},"hasNumbering":false}"#,
+            r#"{"id":"12345678","children":[{"type":"run","data":{"runProperty":{},"children":[{"type":"text","data":{"preserveSpace":true,"text":"Hello"}}]}}],"property":{"runProperty":{},"tabs":[]},"hasNumbering":false}"#,
         );
     }
 
@@ -372,7 +450,17 @@ mod tests {
         let p = Paragraph::new().add_insert(ins);
         assert_eq!(
             serde_json::to_string(&p).unwrap(),
-            r#"{"id":"12345678","children":[{"type":"insert","data":{"children":[{"type":"run","data":{"runProperty":{"sz":null,"szCs":null,"color":null,"highlight":null,"vertAlign":null,"underline":null,"bold":null,"boldCs":null,"italic":null,"italicCs":null,"vanish":null,"characterSpacing":null,"fonts":null,"textBorder":null,"del":null,"ins":null},"children":[{"type":"text","data":{"preserveSpace":true,"text":"Hello"}}]}}],"author":"unnamed","date":"1970-01-01T00:00:00Z"}}],"property":{"runProperty":{"sz":null,"szCs":null,"color":null,"highlight":null,"vertAlign":null,"underline":null,"bold":null,"boldCs":null,"italic":null,"italicCs":null,"vanish":null,"characterSpacing":null,"fonts":null,"textBorder":null,"del":null,"ins":null},"style":null,"numberingProperty":null,"alignment":null,"indent":null,"lineSpacing":null,"keepNext":false,"keepLines":false,"pageBreakBefore":false,"windowControl":false,"outlineLvl":null,"divId":null},"hasNumbering":false}"#
+            r#"{"id":"12345678","children":[{"type":"insert","data":{"children":[{"type":"run","data":{"runProperty":{},"children":[{"type":"text","data":{"preserveSpace":true,"text":"Hello"}}]}}],"author":"unnamed","date":"1970-01-01T00:00:00Z"}}],"property":{"runProperty":{},"tabs":[]},"hasNumbering":false}"#
         );
     }
+
+    #[test]
+    fn test_raw_text() {
+        let b = Paragraph::new()
+            .add_run(Run::new().add_text("Hello"))
+            .add_insert(Insert::new(Run::new().add_text("World")))
+            .add_delete(Delete::new().add_run(Run::new().add_delete_text("!!!!!")))
+            .raw_text();
+        assert_eq!(b, "HelloWorld".to_owned());
+    }
 }
