@@ -8,8 +8,8 @@ use crate::xml_builder::*;
 #[derive(Debug, Clone, Deserialize, PartialEq)]
 #[serde(rename_all = "camelCase")]
 pub struct Text {
-    text: String,
-    preserve_space: bool,
+    pub text: String,
+    pub preserve_space: bool,
 }
 
 impl Text {
