@@ -16,6 +16,8 @@ pub mod section_type;
 pub mod shd_type;
 pub mod special_indent_type;
 pub mod style_type;
+pub mod tab_leader_type;
+pub mod tab_value_type;
 pub mod table_alignment_type;
 pub mod table_layout_type;
 pub mod text_direction_type;
@@ -42,6 +44,8 @@ pub use section_type::*;
 pub use shd_type::*;
 pub use special_indent_type::*;
 pub use style_type::*;
+pub use tab_leader_type::*;
+pub use tab_value_type::*;
 pub use table_alignment_type::*;
 pub use table_layout_type::*;
 pub use text_direction_type::*;
