@@ -1,6 +1,5 @@
 use super::XMLBuilder;
 use super::XmlEvent;
-use crate::types::line_spacing_type::LineSpacingType;
 use crate::types::*;
 
 const EXPECT_MESSAGE: &str = "should write buf";
@@ -24,12 +23,18 @@ impl XMLBuilder {
         self.close()
     }
 
+    #[allow(clippy::too_many_arguments)]
     pub(crate) fn run_fonts(
         mut self,
         ascii: Option<&String>,
         hi_ansi: Option<&String>,
         cs: Option<&String>,
         east_asia: Option<&String>,
+        ascii_theme: Option<&String>,
+        hi_ansi_theme: Option<&String>,
+        cs_theme: Option<&String>,
+        east_asia_theme: Option<&String>,
+        hint: Option<&String>,
     ) -> Self {
         let mut w = XmlEvent::start_element("w:rFonts");
         if let Some(ascii) = ascii {
@@ -44,6 +49,21 @@ impl XMLBuilder {
         if let Some(east_asia) = east_asia {
             w = w.attr("w:eastAsia", east_asia);
         }
+        if let Some(ascii_theme) = ascii_theme {
+            w = w.attr("w:asciiTheme", ascii_theme);
+        }
+        if let Some(hi_ansi_theme) = hi_ansi_theme {
+            w = w.attr("w:hAnsiTheme", hi_ansi_theme);
+        }
+        if let Some(cs_theme) = cs_theme {
+            w = w.attr("w:cstheme", cs_theme);
+        }
+        if let Some(east_asia_theme) = east_asia_theme {
+            w = w.attr("w:eastAsiaTheme", east_asia_theme);
+        }
+        if let Some(hint) = hint {
+            w = w.attr("w:hint", hint);
+        }
         self.writer.write(w).expect(EXPECT_MESSAGE);
         self.close()
     }
@@ -82,6 +102,26 @@ impl XMLBuilder {
         self.close()
     }
 
+    pub(crate) fn open_hyperlink(
+        mut self,
+        rid: Option<&String>,
+        anchor: Option<&String>,
+        history: bool,
+    ) -> Self {
+        let mut e = XmlEvent::start_element("w:hyperlink");
+        if let Some(rid) = rid {
+            e = e.attr("w:rid", rid);
+        }
+        if let Some(anchor) = anchor {
+            e = e.attr("w:anchor", anchor);
+        }
+        if history {
+            e = e.attr("w:history", "true");
+        }
+        self.writer.write(e).expect(EXPECT_MESSAGE);
+        self
+    }
+
     // i.e. <w:r ... >
     open!(open_run, "w:r");
     open!(open_run_property, "w:rPr");
@@ -97,6 +137,7 @@ impl XMLBuilder {
     open!(open_structured_tag, "w:sdt");
     open!(open_structured_tag_content, "w:sdtContent");
     open!(open_structured_tag_property, "w:sdtPr");
+    closed_with_str!(alias, "w:alias");
 
     // i.e. <w:outlineLvl ...>
     closed_with_usize!(outline_lvl, "w:outlineLvl");
@@ -124,6 +165,9 @@ impl XMLBuilder {
 
     closed!(i, "w:i");
     closed!(i_cs, "w:iCs");
+
+    closed!(strike, "w:strike");
+
     // Build w:style element
     // i.e. <w:style ... >
     pub(crate) fn open_style(mut self, style_type: StyleType, id: &str) -> Self {
@@ -290,7 +334,6 @@ impl XMLBuilder {
 
     closed!(shd, "w:shd", "w:val", "w:color", "w:fill");
 
-    closed!(tab, "w:tab");
     closed!(tab_with_pos, "w:tab", "w:val", "w:pos");
 
     closed!(br, "w:br", "w:type");
@@ -327,6 +370,13 @@ impl XMLBuilder {
 
     open!(open_insert, "w:ins", "w:id", "w:author", "w:date");
     open!(open_delete, "w:del", "w:id", "w:author", "w:date");
+    open!(
+        open_paragraph_property_change,
+        "w:pPrChange",
+        "w:id",
+        "w:author",
+        "w:date"
+    );
 
     closed!(bookmark_start, "w:bookmarkStart", "w:id", "w:name");
     closed!(bookmark_end, "w:bookmarkEnd", "w:id");
@@ -391,7 +441,7 @@ impl XMLBuilder {
     closed!(keep_next, "w:keepNext");
     closed!(keep_lines, "w:keepLines");
     closed!(page_break_before, "w:pageBreakBefore");
-    closed!(window_control, "w:windowControl");
+    closed!(widow_control, "w:widowControl");
 
     /*
     <w:lvlOverride w:ilvl="0">
@@ -493,6 +543,43 @@ impl XMLBuilder {
 
         self.close()
     }
+
+    pub(crate) fn tab(
+        mut self,
+        v: Option<TabValueType>,
+        leader: Option<TabLeaderType>,
+        pos: Option<usize>,
+    ) -> Self {
+        let v_string = if let Some(v) = v {
+            v.to_string()
+        } else {
+            "".to_string()
+        };
+
+        let leader_string = if let Some(leader) = leader {
+            leader.to_string()
+        } else {
+            "".to_string()
+        };
+
+        let pos_string = format!("{}", pos.unwrap_or_default());
+
+        let mut t = XmlEvent::start_element("w:tab");
+        if v.is_some() {
+            t = t.attr("w:val", &v_string);
+        }
+
+        if leader.is_some() {
+            t = t.attr("w:leader", &leader_string);
+        }
+
+        if pos.is_some() {
+            t = t.attr("w:pos", &pos_string);
+        }
+        self.writer.write(t).expect(EXPECT_MESSAGE);
+
+        self.close()
+    }
 }
 
 #[cfg(test)]
